A sandwich.ci object that contains the estimated mean and standard deviation for each reporting unit.
Arguments
object
When type="shp", object is a list of three sf objects generated by load.data.shp, including a point sf object used as the sampling layer, a polygon sf object used as the SSH layer, and a polygon sf object used as the SSH layer. When type="txt", object is a list of two data frames generated by load.data.txt, including a file linking sampling and SSH layers and a file linking reporting and SSH layers.
sampling.attr
Text for the name of the attribute to be predicted in the sampling layer.
type
Text for the type of input data. type="shp" denotes shapefiles, and type="txt" denotes text files. By default, type="shp".
ssh.id.col
Text for the column that specifies which stratum each sampling unit falls into (see load.data.txt). Set to NULL when type="shp".
ssh.weights
A list that specifies the strata in the SSH layer and their corresponding columns of weights in reporting_ssh.file (see load.data.txt).
References
Wang, J. F., Haining, R., Liu, T. J., Li, L. F., & Jiang, C. S. (2013). Sandwich estimation for multi-unit reporting on a stratified heterogeneous surface. Environment and Planning A, 45(10), 2515-2534.