A sandwich.model object generated by sandwich.model.
titles
A list of texts for the titles.
labels
A list of texts for the legend labels.
border_color
Color for outlines of the polygons.
poly_fill_mean
A list of colors for low and high ends of the gradient in the mapping of means.
poly_fill_se
A list of colors for low and high ends of the gradient in the mapping of standard errors.
...
Ignored.
References
Wang, J. F., Haining, R., Liu, T. J., Li, L. F., & Jiang, C. S. (2013). Sandwich estimation for multi-unit reporting on a stratified heterogeneous surface. Environment and Planning A, 45(10), 2515-2534.